
---------------------
-- Local Variables --
---------------------
local screenWidth, screenHeight = love.graphics.getDimensions()
local centerX, centerY = screenWidth/2, screenHeight/2
  
  
------------
-- Object --
------------
local object = {}

function object:init(x, y)
  self.x          = x or 0
  self.y          = y or 0
  self.width      = 32
  self.height     = 32
  self.xvel       = 300
end


function object:update(dt)
  local mx, my = love.mouse.getPosition()
  local left, right = mx < centerX, mx > centerX
  
  -- Move --
  if love.mouse.isDown(1) and left then
    self.x = self.x - self.xvel * dt 
  elseif love.mouse.isDown(1) and right then
    self.x = self.x + self.xvel * dt
  end
  
  -- Set back onto screen --
  if self.x < 0 then self.x = 0 
  elseif self.x > screenWidth-self.width then self.x = screenWidth-self.width end
end


function object:draw()
  love.graphics.setColor(255, 150, 50)
  love.graphics.rectangle("fill", self.x, self.y, self.width, self.height)
  love.graphics.setColor(255, 255, 255)
end



--------------------
-- Main callbacks --
--------------------
function love.load()
  object:init(centerX-16, centerY-16)
end


function love.update(dt)
  object:update(dt)
end


function love.draw()
  love.graphics.line(centerX, 0, centerX, screenWidth)
  object:draw()
  love.graphics.print("Escape to quit")
end


function love.keypressed(key)
  if key == "escape" then love.event.quit() end
end
